==> rendition-11.7.1.tgz: package/dist_esm5/unstable/components/Form/templates/ArrayFieldTemplate.js <==
import * as tslib_1 from "tslib";
import * as React from 'react';
import FaArrowDown from 'react-icons/lib/fa/arrow-down';
import FaArrowUp from 'react-icons/lib/fa/arrow-up';
import FaClose from 'react-icons/lib/fa/close';
import FaPlus from 'react-icons/lib/fa/plus';
import styled from 'styled-components';
import { Box, Button, Flex } from '../../../../';
import { WarningField } from '../WarningField';
var ArrayFieldTitle = function (_a) {
    var TitleField = _a.TitleField, idSchema = _a.idSchema, required = _a.required, title = _a.title;
    if (!title) {
        return null;
    }
    var id = idSchema.$id + "__title";
    return React.createElement(TitleField, { id: id, title: title, required: required });
};
var ArrayFieldDescription = function (_a) {
    var DescriptionField = _a.DescriptionField, idSchema = _a.idSchema, description = _a.description;
    if (!description) {
        return null;
    }
    var id = idSchema.$id + "__description";
    return React.createElement(DescriptionField, { id: id, description: description });
};
var ActionButton = styled(Button)(templateObject_1 || (templateObject_1 = tslib_1.__makeTemplateObject(["\n\tcolor: ", ";\n"], ["\n\tcolor: ", ";\n"])), function (_a) {
    var theme = _a.theme;
    return theme.colors.text.light;
});
export default (function (props) {
    var warning = props.uiSchema['ui:warning'];
    return (React.createElement("div", { className: props.uiSchema.classNames },
        React.createElement(ArrayFieldTitle, { TitleField: props.TitleField, idSchema: props.idSchema, title: props.uiSchema['ui:title'] || props.title, required: props.required }),
        !!warning && React.createElement(WarningField, { warning: warning }),
        React.createElement(ArrayFieldDescription, { DescriptionField: props.DescriptionField, idSchema: props.idSchema, description: props.uiSchema['ui:description'] || props.schema.description }),
        props.items.map(function (element) {
            return (React.createElement("div", { className: "rendition-form__array-item", key: element.index },
                React.createElement(Flex, { alignItems: "flex-start" },
                    React.createElement(Box, { flex: "1" }, element.children),
                    props.items.length > 1 && (React.createElement(ActionButton, { type: "button", className: "rendition-form-array-item__move-up", mb: "6px", px: 1, mt: 1, ml: 1, plain: true, disabled: element.disabled || element.readonly || !element.hasMoveUp, onClick: element.onReorderClick(element.index, element.index - 1) },
                        React.createElement(FaArrowUp, null))),
                    props.items.length > 1 && (React.createElement(ActionButton, { type: "button", className: "rendition-form-array-item__move-down", mb: "6px", px: 1, mt: 1, ml: 1, plain: true, disabled: element.disabled || element.readonly || !element.hasMoveDown, onClick: element.onReorderClick(element.index, element.index + 1) },
                        React.createElement(FaArrowDown, null))),
                    element.hasRemove && (React.createElement(ActionButton, { type: "button", className: "rendition-form-array-item__remove-item", plain: true, mb: "6px", mt: 1, px: 1, ml: 1, disabled: element.disabled || element.readonly, onClick: element.onDropIndexClick(element.index) },
                        React.createElement(FaClose, null))))));
        }),
        props.canAdd && (React.createElement(Button, { type: "button", className: "rendition-form-array-item__add-item", icon: React.createElement(FaPlus, null), onClick: props.onAddClick }, "Add item"))));
});
var templateObject_1;

==> rendition-11.16.4.tgz: package/dist_esm5/unstable/components/Form/templates/ArrayFieldTemplate.js <==
import { __makeTemplateObject } from "tslib";
import * as React from 'react';
import FaArrowDown from 'react-icons/lib/fa/arrow-down';
import FaArrowUp from 'react-icons/lib/fa/arrow-up';
import FaClose from 'react-icons/lib/fa/close';
import FaPlus from 'react-icons/lib/fa/plus';
import styled from 'styled-components';
import { Box, Button, Flex } from '../../../../';
import { WarningField } from '../WarningField';
var ArrayFieldTitle = function (_a) {
    var TitleField = _a.TitleField, idSchema = _a.idSchema, required = _a.required, title = _a.title;
    if (!title) {
        return null;
    }
    var id = idSchema.$id + "__title";
    return React.createElement(TitleField, { id: id, title: title, required: required });
};
var ArrayFieldDescription = function (_a) {
    var DescriptionField = _a.DescriptionField, idSchema = _a.idSchema, description = _a.description;
    if (!description) {
        return null;
    }
    var id = idSchema.$id + "__description";
    return React.createElement(DescriptionField, { id: id, description: description });
};
var ActionButton = styled(Button)(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n\tcolor: ", ";\n"], ["\n\tcolor: ", ";\n"])), function (_a) {
    var theme = _a.theme;
    return theme.colors.text.light;
});
export default (function (props) {
    var warning = props.uiSchema['ui:warning'];
    return (React.createElement("div", { className: props.uiSchema.classNames },
        React.createElement(ArrayFieldTitle, { TitleField: props.TitleField, idSchema: props.idSchema, title: props.uiSchema['ui:title'] || props.title, required: props.required }),
        !!warning && React.createElement(WarningField, { warning: warning }),
        React.createElement(ArrayFieldDescription, { DescriptionField: props.DescriptionField, idSchema: props.idSchema, description: props.uiSchema['ui:description'] || props.schema.description }),
        props.items.map(function (element) {
            return (React.createElement("div", { className: "rendition-form__array-item", key: element.index },
                React.createElement(Flex, { alignItems: "flex-start" },
                    React.createElement(Box, { flex: "1" }, element.children),
                    props.items.length > 1 && (React.createElement(ActionButton, { type: "button", className: "rendition-form-array-item__move-up", mb: "6px", px: 1, mt: 1, ml: 1, plain: true, disabled: element.disabled || element.readonly || !element.hasMoveUp, onClick: element.onReorderClick(element.index, element.index - 1) },
                        React.createElement(FaArrowUp, null))),
                    props.items.length > 1 && (React.createElement(ActionButton, { type: "button", className: "rendition-form-array-item__move-down", mb: "6px", px: 1, mt: 1, ml: 1, plain: true, disabled: element.disabled || element.readonly || !element.hasMoveDown, onClick: element.onReorderClick(element.index, element.index + 1) },
                        React.createElement(FaArrowDown, null))),
                    element.hasRemove && (React.createElement(ActionButton, { type: "button", className: "rendition-form-array-item__remove-item", plain: true, mb: "6px", mt: 1, px: 1, ml: 1, disabled: element.disabled || element.readonly, onClick: element.onDropIndexClick(element.index) },
                        React.createElement(FaClose, null))))));
        }),
        props.canAdd && (React.createElement(Button, { type: "button", className: "rendition-form-array-item__add-item", icon: React.createElement(FaPlus, null), onClick: props.onAddClick }, "Add item"))));
});
var templateObject_1;
